package io.reisub.openosrs.util.tasks;

import io.reisub.openosrs.util.Task;
import net.runelite.api.Skill;

public class Eat extends Task {
    private long last = 0;
    private boolean wait = true;
    private int threshold = 5;
    private int mean = 5;
    private int sigma = 1;

    public void setInterval(int min, int max) {
        mean = (min + max) / 2;
        sigma = mean - min;

        if (sigma <= 0) threshold = min;

        threshold = getNewThreshold();
    }

    public void setWait(boolean wait) {
        this.wait = wait;
    }

    @Override
    public boolean validate() {
        return game.modifiedLevel(Skill.HITPOINTS) <= threshold
                && game.inventory().withAction("Eat", "Drink").findAny().isPresent()
                && System.currentTimeMillis() > last + 1800;
    }

    @Override
    public void execute() {
        int hp = game.modifiedLevel(Skill.HITPOINTS);

        game.inventory().withAction("Eat", "Drink").findFirst().ifPresent(inventoryItem -> {
            if (inventoryItem.actions().contains("Eat")) {
                inventoryItem.interact("Eat");
            } else {
                inventoryItem.interact("Drink");
            }
            last = System.currentTimeMillis();
        });
        if (wait) game.tick();

        threshold = getNewThreshold();

        if (wait) game.waitUntil(() -> hp < game.modifiedLevel(Skill.HITPOINTS), 10);
    }

    private int getNewThreshold() {
        if (sigma <= 0) {
            return threshold;
        }

        return calc.randomGauss(1, 99, sigma, mean, false);
    }

    @Override
    public String getStatus() {
        return "Eating";
    }
}
